rm(list=ls())

#importing the data file
library(xlsx)
wine <- read.xlsx(file="french_wine_dca.xls",sheetIndex=1,header=T)
print(summary(wine))

#select the predictive attributes
descriptors <- subset(wine,select=-1)
print(summary(descriptors))

#function for building crosstabs from the target attribute
#and each predictive attributes
cross.tab <- function(x,ref){
 m <- table(ref,x)
 return(m)
}

#apply the function cross.tab on each predictive attribute
dataset <- lapply(descriptors,cross.tab,ref=wine$Region)

#create the matrix for the correspondence analysis
#from the crosstabs
matrix.ca <- NULL
for (j in 1:ncol(descriptors)){
 m <- dataset[[j]]
 colnames(m) <- paste(colnames(descriptors)[j],colnames(m),sep=".")
 matrix.ca <- cbind(matrix.ca,m)
}
print(matrix.ca)

#***************************************************
#perform the correspondence analysis from the matrix
#using the 'ca' package
#***************************************************
library(ca)
fit <- ca(matrix.ca,nd=2)
print(fit)

#graphical representation
plot(fit)

#row coordinates (consistent with Tanagra)
row.coord <- cbind(fit$rowcoord[,1]*fit$sv[1],fit$rowcoord[,2]*fit$sv[2])
rownames(row.coord) <- rownames(matrix.ca)
print(row.coord)

#column coordinates (consistent with Tanagra)
col.coord <- cbind(fit$colcoord[,1]*fit$sv[1],fit$colcoord[,2]*fit$sv[2])
rownames(col.coord) <- colnames(matrix.ca)
print(col.coord)
